import enum

class Auto_Mode(enum.Enum):
    disable: int
    normal: int
    high: int
    highest: int

def isEntryPoint(): ...
def get_real_exe_dir() -> str: ...
def get_temp_path(relative_path: str = ...): ...
def print_file_tree(path) -> None: ...
def is_nuitka_packaged() -> bool: ...
def is_pyinstaller_packaged() -> bool: ...
def copy_file_to(becopyed_file_path: str, new_file_path: str, cover: bool = ..., file_name: str = ...): ...
def getProjectPath(layer: int = ..., auto: Auto_Mode = ...) -> str: ...



from PyQt5.QtCore import QRect
from PyQt5.QtWidgets import QMainWindow, QWidget
from typing import Union

def get_center_screenGeometry(window: Union[QWidget, QMainWindow], width: int = ..., height: int = ...) -> Union[QRect, None]: ...
def setAntiScreenShot(window: int | QWidget): ...

class n_qthread: ...



from .ncontainer import *
from .nio import *
from .nout import *
from .nstr import *

# ncontainer.py

# nio.py
import shutil
import sys
import os
import enum
import inspect
import pathlib

# nout.py
import inspect
import os

# nstr.py
import re